@@ -4,6 +4,7 @@ from plone.memoize.instance import memoize
 from zope.component import getUtility
 from plone.registry.interfaces import IRegistry
 from ..interfaces import IGooglefontsSettings
+from ..vocabularies import fonts
 
 class GooglefontsHead(ViewletBase):
     
@@ -19,7 +20,11 @@ class GooglefontsHead(ViewletBase):
     @property
     def construct_url(self):
         """returns the googleapis font url """
-        url = 'http://fonts.googleapis.com/css?family=' +  ("|".join(str(font) for font in self.fontfamily))
-        return url
+        return ['http://fonts.googleapis.com/css?family=' +  ("|".join(str(font) for font in self.fontfamily))]
+        
+    @property
+    def fontfamilies(self):
+        """Returns  fontfamilies taken from registry."""
+        return  fonts(self)
+
 
-    
\ No newline at end of file
